@@ -271,6 +271,9 @@ void AbstractImportExportJob::convertRealPathToCollectionList(KConfigGroup &grou
 
 Akonadi::Collection::Id AbstractImportExportJob::convertPathToId(const QString &path)
 {
+    if (path.isEmpty()) {
+        return -1;
+    }
     Akonadi::Collection::Id val = mHashConvertPathCollectionId.value(path, -1);
     if (val != -1) {
         return val;
@@ -619,3 +622,12 @@ void AbstractImportExportJob::importDataSubdirectory(const QString &subdirectory
         }
     }
 }
+
+void AbstractImportExportJob::convertCollectionStrToAkonadiId(const KSharedConfig::Ptr &config, const QString &groupName, const QString &key)
+{
+    if (config->hasGroup(groupName)) {
+        KConfigGroup eventGroup = config->group(groupName);
+        const QString eventLastEventSelectedFolder(key);
+        convertRealPathToCollection(eventGroup, eventLastEventSelectedFolder, false);
+    }
+}
