@@ -18,6 +18,7 @@
 */
 
 #include "exportmailjob.h"
+#include "importexportmailutil.h"
 
 #include "MailCommon/MailUtil"
 #include "MailCommon/FilterManager"
@@ -45,6 +46,9 @@
 #include <exportresourcearchivejob.h>
 #include <QRegularExpression>
 
+#include <KIdentityManagement/IdentityManager>
+#include <KIdentityManagement/Identity>
+
 ExportMailJob::ExportMailJob(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep)
     : AbstractImportExportJob(parent, archiveStorage, typeSelected, numberOfStep)
 {
@@ -270,9 +274,10 @@ void ExportMailJob::backupConfig()
     if (!lstFilter.isEmpty()) {
         QTemporaryFile tmp;
         tmp.open();
-        QUrl url(tmp.fileName());
+        QUrl url = QUrl::fromLocalFile(tmp.fileName());
         MailCommon::FilterImporterExporter exportFilters;
         exportFilters.exportFilters(lstFilter, url, true);
+        tmp.close();
         const bool fileAdded = archive()->addLocalFile(tmp.fileName(), Utils::configsPath() + QLatin1String("filters"));
         if (fileAdded) {
             Q_EMIT info(i18n("Filters backup done."));
@@ -455,6 +460,7 @@ void ExportMailJob::backupConfig()
             const int collectionId = str.rightRef(str.length() - folderGroupPattern.length()).toInt(&found);
             if (found) {
                 KConfigGroup oldGroup = kmailConfig->group(str);
+                ImportExportMailUtil::cleanupFolderSettings(oldGroup);
                 const QString realPath = MailCommon::Util::fullCollectionPath(Akonadi::Collection(collectionId));
                 if (!realPath.isEmpty()) {
                     KConfigGroup newGroup(kmailConfig, folderGroupPattern + realPath);
@@ -527,6 +533,73 @@ void ExportMailJob::backupConfig()
             Utils::convertCollectionIdsToRealPath(favoriteGroup, favoriteCollectionIdsStr);
         }
 
+        const QString favoriteCollectionOrderStr(QStringLiteral("FavoriteCollectionsOrder"));
+        if (kmailConfig->hasGroup(favoriteCollectionOrderStr)) {
+            KConfigGroup favoriteGroup = kmailConfig->group(favoriteCollectionOrderStr);
+            //For favorite id for root collection == 0 and we store only folder => c
+            const QString favoriteCollectionIdsStr(QStringLiteral("0"));
+            const QString prefixCollection(QStringLiteral("c"));
+            Utils::convertCollectionIdsToRealPath(favoriteGroup, favoriteCollectionIdsStr, prefixCollection);
+        }
+
+        //Event collection
+        const QString eventCollectionStr(QStringLiteral("Event"));
+        if (kmailConfig->hasGroup(eventCollectionStr)) {
+            KConfigGroup eventGroup = kmailConfig->group(eventCollectionStr);
+            const QString eventLastEventSelectedFolder(QStringLiteral("LastEventSelectedFolder"));
+            Utils::convertCollectionIdsToRealPath(eventGroup, eventLastEventSelectedFolder);
+        }
+
+        //Todo collection
+        const QString todoCollectionStr(QStringLiteral("Todo"));
+        if (kmailConfig->hasGroup(todoCollectionStr)) {
+            KConfigGroup todoGroup = kmailConfig->group(todoCollectionStr);
+            const QString todoLastEventSelectedFolder(QStringLiteral("LastSelectedFolder"));
+            Utils::convertCollectionIdsToRealPath(todoGroup, todoLastEventSelectedFolder);
+        }
+        //FolderSelectionDialog collection
+        const QString folderSelectionCollectionStr(QStringLiteral("FolderSelectionDialog"));
+        if (kmailConfig->hasGroup(folderSelectionCollectionStr)) {
+            KConfigGroup folderSelectionGroup = kmailConfig->group(folderSelectionCollectionStr);
+            const QString folderSelectionSelectedFolder(QStringLiteral("LastSelectedFolder"));
+            Utils::convertCollectionIdsToRealPath(folderSelectionGroup, folderSelectionSelectedFolder);
+        }
+
+        //Note collection
+        const QString noteCollectionStr(QStringLiteral("Note"));
+        if (kmailConfig->hasGroup(noteCollectionStr)) {
+            KConfigGroup noteGroup = kmailConfig->group(noteCollectionStr);
+            const QString noteLastEventSelectedFolder(QStringLiteral("LastNoteSelectedFolder"));
+            Utils::convertCollectionIdsToRealPath(noteGroup, noteLastEventSelectedFolder);
+        }
+
+        //Convert MessageListTab collection id
+        const QString messageListPaneStr(QStringLiteral("MessageListPane"));
+        if (kmailConfig->hasGroup(messageListPaneStr)) {
+            KConfigGroup messageListPaneGroup = kmailConfig->group(messageListPaneStr);
+            const int numberOfTab = messageListPaneGroup.readEntry(QStringLiteral("tabNumber"), 0);
+            for (int i = 0; i < numberOfTab; ++i) {
+                KConfigGroup messageListPaneTabGroup = kmailConfig->group(QStringLiteral("MessageListTab%1").arg(i));
+                const QString messageListPaneTabFolderStr(QStringLiteral("collectionId"));
+                Utils::convertCollectionIdsToRealPath(messageListPaneTabGroup, messageListPaneTabFolderStr);
+            }
+        }
+
+        //Automatic Add Contacts
+        KIdentityManagement::IdentityManager *im = KIdentityManagement::IdentityManager::self();
+        KIdentityManagement::IdentityManager::ConstIterator end = im->end();
+        for (KIdentityManagement::IdentityManager::ConstIterator it = im->begin(); it != end; ++it) {
+            const uint identity = (*it).uoid();
+            const QString groupId = QStringLiteral("Automatic Add Contacts %1").arg(identity);
+            if (kmailConfig->hasGroup(groupId)) {
+                KConfigGroup identityGroup = kmailConfig->group(groupId);
+                const QString automaticAddContactStr(QStringLiteral("Collection"));
+                Utils::convertCollectionIdsToRealPath(identityGroup, automaticAddContactStr);
+            }
+        }
+
+        //TODO add confirm address too
+
         kmailConfig->sync();
         backupFile(tmp.fileName(), Utils::configsPath(), kmailStr);
         delete kmailConfig;
