@@ -19,6 +19,7 @@
 
 #include "importmailjob.h"
 #include "archivestorage.h"
+#include "importexportmailutil.h"
 
 #include "MailCommon/FilterManager"
 #include "MailCommon/FilterImporterExporter"
@@ -312,7 +313,22 @@ void ImportMailJob::restoreResources()
     QDir dir(mTempDirName);
     dir.mkdir(Utils::resourcesPath());
     for (const QString &filename : qAsConst(mFileList)) {
-        if (filename.startsWith(Utils::resourcesPath())) {
+        //We need to find akonadi_* and agent_config_akonadi_*
+        if (filename.startsWith(Utils::resourcesPath() + QStringLiteral("akonadi_"))) {
+            const QString agentFileConfigName = Utils::agentFileName(filename);
+            QString resourceName;
+            if (mFileList.contains(agentFileConfigName)) {
+                //Parse config file => get name
+                const KArchiveEntry *agentFileConfigEntry = mArchiveDirectory->entry(agentFileConfigName);
+                if (agentFileConfigEntry && agentFileConfigEntry->isFile()) {
+                    const KArchiveFile *file = static_cast<const KArchiveFile *>(agentFileConfigEntry);
+                    const QString destDirectory = mTempDirName + QLatin1Char('/') + Utils::resourcesPath();
+                    file->copyTo(destDirectory);
+                    const QString filename(file->name());
+                    const QString agentResourceFileName = destDirectory + QLatin1Char('/') + filename;
+                    resourceName = Utils::akonadiAgentName(agentResourceFileName);
+                }
+            }
             const KArchiveEntry *fileEntry = mArchiveDirectory->entry(filename);
             if (fileEntry && fileEntry->isFile()) {
                 const KArchiveFile *file = static_cast<const KArchiveFile *>(fileEntry);
@@ -395,7 +411,8 @@ void ImportMailJob::restoreResources()
                     if (leaveOnserver.hasKey(QStringLiteral("downloadLater"))) {
                         settings.insert(QStringLiteral("DownloadLater"), leaveOnserver.readEntry("downloadLater", QStringList()));
                     }
-                    const QString newResource = mCreateResource->createResource(QStringLiteral("akonadi_pop3_resource"), filename, settings);
+                    const QString newResourceName = resourceName.isEmpty() ? filename : resourceName;
+                    const QString newResource = mCreateResource->createResource(QStringLiteral("akonadi_pop3_resource"), newResourceName, settings);
                     if (!newResource.isEmpty()) {
                         mHashResources.insert(filename, newResource);
                         infoAboutNewResource(newResource);
@@ -491,12 +508,13 @@ void ImportMailJob::restoreResources()
                     }
 
                     QString newResource;
+                    const QString newResourceName = resourceName.isEmpty() ? filename : resourceName;
                     if (filename.contains(QLatin1String("kolab_"))) {
-                        newResource = mCreateResource->createResource(QStringLiteral("akonadi_kolab_resource"), filename, settings);
+                        newResource = mCreateResource->createResource(QStringLiteral("akonadi_kolab_resource"), newResourceName, settings);
                     } else if (filename.contains(QLatin1String("gmail_"))) {
-                        newResource = mCreateResource->createResource(QStringLiteral("akonadi_gmail_resource"), filename, settings);
+                        newResource = mCreateResource->createResource(QStringLiteral("akonadi_gmail_resource"), newResourceName, settings);
                     } else {
-                        newResource = mCreateResource->createResource(QStringLiteral("akonadi_imap_resource"), filename, settings);
+                        newResource = mCreateResource->createResource(QStringLiteral("akonadi_imap_resource"), newResourceName, settings);
                     }
                     if (!newResource.isEmpty()) {
                         mHashResources.insert(filename, newResource);
@@ -1091,32 +1109,32 @@ void ImportMailJob::importTemplatesConfig(const KArchiveFile *templatesconfigura
 
     //adapt id
     const QString templateGroupPattern = QStringLiteral("Templates #");
+    const QString templateGroupIdentityPattern = QStringLiteral("Templates #IDENTITY_");
     const QStringList templateList = templateConfig->groupList().filter(templateGroupPattern);
     for (const QString &str : templateList) {
-        const QString path = str.right(str.length() - templateGroupPattern.length());
-        if (!path.isEmpty()) {
-            KConfigGroup oldGroup = templateConfig->group(str);
-            const Akonadi::Collection::Id id = convertPathToId(path);
-            if (id != -1) {
-                KConfigGroup newGroup(templateConfig, templateGroupPattern + QString::number(id));
-                oldGroup.copyTo(&newGroup);
+        //Identity
+        if (str.startsWith(templateGroupIdentityPattern)) {
+            bool found = false;
+            const int identity = str.rightRef(str.length() - templateGroupIdentityPattern.length()).toInt(&found);
+            if (found) {
+                KConfigGroup oldGroup = templateConfig->group(str);
+                if (mHashIdentity.contains(identity)) {
+                    KConfigGroup newGroup(templateConfig, templateGroupPattern + QString::number(mHashIdentity.value(identity)));
+                    oldGroup.copyTo(&newGroup);
+                }
+                oldGroup.deleteGroup();
             }
-            oldGroup.deleteGroup();
-        }
-    }
-    //adapt identity
-    const QString templateGroupIdentityPattern = QStringLiteral("Templates #IDENTITY_");
-    const QStringList templateListIdentity = templateConfig->groupList().filter(templateGroupIdentityPattern);
-    for (const QString &str : templateListIdentity) {
-        bool found = false;
-        const int identity = str.rightRef(str.length() - templateGroupIdentityPattern.length()).toInt(&found);
-        if (found) {
-            KConfigGroup oldGroup = templateConfig->group(str);
-            if (mHashIdentity.contains(identity)) {
-                KConfigGroup newGroup(templateConfig, templateGroupPattern + QString::number(mHashIdentity.value(identity)));
-                oldGroup.copyTo(&newGroup);
+        } else { //Folder
+            const QString path = str.right(str.length() - templateGroupPattern.length());
+            if (!path.isEmpty()) {
+                KConfigGroup oldGroup = templateConfig->group(str);
+                const Akonadi::Collection::Id id = convertPathToId(path);
+                if (id != -1) {
+                    KConfigGroup newGroup(templateConfig, templateGroupPattern + QString::number(id));
+                    oldGroup.copyTo(&newGroup);
+                }
+                oldGroup.deleteGroup();
             }
-            oldGroup.deleteGroup();
         }
     }
     templateConfig->sync();
@@ -1141,10 +1159,13 @@ void ImportMailJob::importKmailConfig(const KArchiveFile *kmailsnippet, const QS
         const QString path = str.right(str.length() - folderGroupPattern.length());
         if (!path.isEmpty()) {
             KConfigGroup oldGroup = kmailConfig->group(str);
-            const Akonadi::Collection::Id id = convertPathToId(path);
-            if (id != -1) {
-                KConfigGroup newGroup(kmailConfig, folderGroupPattern + QString::number(id));
-                oldGroup.copyTo(&newGroup);
+            ImportExportMailUtil::cleanupFolderSettings(oldGroup);
+            if (!oldGroup.groupList().isEmpty()) {
+                const Akonadi::Collection::Id id = convertPathToId(path);
+                if (id != -1) {
+                    KConfigGroup newGroup(kmailConfig, folderGroupPattern + QString::number(id));
+                    oldGroup.copyTo(&newGroup);
+                }
             }
             oldGroup.deleteGroup();
         }
@@ -1194,6 +1215,70 @@ void ImportMailJob::importKmailConfig(const KArchiveFile *kmailsnippet, const QS
         convertRealPathToCollectionList(favoriteGroup, expensionKey);
     }
 
+
+    const QString favoriteCollectionStr(QStringLiteral("FavoriteCollections"));
+    if (kmailConfig->hasGroup(favoriteCollectionStr)) {
+        KConfigGroup favoriteGroup = kmailConfig->group(favoriteCollectionStr);
+
+        const QString favoriteCollectionIdsStr(QStringLiteral("FavoriteCollectionIds"));
+        convertRealPathToCollectionList(favoriteGroup, favoriteCollectionIdsStr, false);
+    }
+
+    const QString favoriteCollectionOrderStr(QStringLiteral("FavoriteCollectionsOrder"));
+    if (kmailConfig->hasGroup(favoriteCollectionOrderStr)) {
+        KConfigGroup favoriteGroupOrder = kmailConfig->group(favoriteCollectionOrderStr);
+
+        //For favorite id for root collection == 0 and we store only folder => c
+        const QString favoriteCollectionOrderIdsStr(QStringLiteral("0"));
+        convertRealPathToCollectionList(favoriteGroupOrder, favoriteCollectionOrderIdsStr, true);
+    }
+
+    //Event collection
+    convertCollectionStrToAkonadiId(kmailConfig, QStringLiteral("Event"), QStringLiteral("LastEventSelectedFolder"));
+    //Todo collection
+    convertCollectionStrToAkonadiId(kmailConfig, QStringLiteral("Todo"), QStringLiteral("LastSelectedFolder"));
+    //Note collection
+    convertCollectionStrToAkonadiId(kmailConfig, QStringLiteral("Note"), QStringLiteral("LastNoteSelectedFolder"));
+
+    //FolderSelectionDialog collection
+    const QString folderSelectionCollectionStr(QStringLiteral("FolderSelectionDialog"));
+    if (kmailConfig->hasGroup(folderSelectionCollectionStr)) {
+        KConfigGroup folderSelectionGroup = kmailConfig->group(folderSelectionCollectionStr);
+        const QString folderSelectionSelectedFolder(QStringLiteral("LastSelectedFolder"));
+        convertRealPathToCollectionList(folderSelectionGroup, folderSelectionSelectedFolder, false);
+    }
+
+
+    //Convert MessageListTab collection id
+    const QString messageListPaneStr(QStringLiteral("MessageListPane"));
+    if (kmailConfig->hasGroup(messageListPaneStr)) {
+        KConfigGroup messageListPaneGroup = kmailConfig->group(messageListPaneStr);
+        const int numberOfTab = messageListPaneGroup.readEntry(QStringLiteral("tabNumber"), 0);
+        for (int i = 0; i < numberOfTab; ++i) {
+            KConfigGroup messageListPaneTabGroup = kmailConfig->group(QStringLiteral("MessageListTab%1").arg(i));
+            const QString messageListPaneTabFolderStr(QStringLiteral("collectionId"));
+            convertRealPathToCollectionList(messageListPaneTabGroup, messageListPaneTabFolderStr, false);
+        }
+    }
+
+
+    //Automatic Add Contacts
+    QHash<int, uint>::const_iterator i = mHashIdentity.constBegin();
+    while (i != mHashIdentity.constEnd()) {
+        //Use old key
+        const QString groupId = QStringLiteral("Automatic Add Contacts %1").arg(i.key());
+        if (kmailConfig->hasGroup(groupId)) {
+            KConfigGroup identityGroup = kmailConfig->group(groupId);
+
+            KConfigGroup newGroup(kmailConfig, QStringLiteral("Automatic Add Contacts %1").arg(i.value()));
+            identityGroup.copyTo(&newGroup);
+            const QString automaticAddContactStr(QStringLiteral("Collection"));
+            Utils::convertCollectionIdsToRealPath(newGroup, automaticAddContactStr);
+            identityGroup.deleteGroup();
+        }
+        ++i;
+    }
+
     const QString generalStr(QStringLiteral("General"));
     if (kmailConfig->hasGroup(generalStr)) {
         KConfigGroup generalGroup = kmailConfig->group(generalStr);
@@ -1247,37 +1332,39 @@ void ImportMailJob::mergeLdapConfig(const KArchiveFile *archivefile, const QStri
 
     for (int i = 0; i < importingNumberSelectedHosts; ++i) {
         const QString auth = grpImporting.readEntry(QStringLiteral("SelectedAuth%1").arg(i), QString());
-        grpExisting.writeEntry(QStringLiteral("SelectedAuth%1").arg(existingNumberSelectedHosts + i + 1), auth);
-        grpExisting.writeEntry(QStringLiteral("SelectedBase%1").arg(existingNumberSelectedHosts + i + 1), grpImporting.readEntry(QStringLiteral("SelectedBase%1").arg(i), QString()));
-        grpExisting.writeEntry(QStringLiteral("SelectedBind%1").arg(existingNumberSelectedHosts + i + 1), grpImporting.readEntry(QStringLiteral("SelectedBind%1").arg(i), QString()));
-        grpExisting.writeEntry(QStringLiteral("SelectedHost%1").arg(existingNumberSelectedHosts + i + 1), grpImporting.readEntry(QStringLiteral("SelectedHost%1").arg(i), QString()));
-        grpExisting.writeEntry(QStringLiteral("SelectedMech%1").arg(existingNumberSelectedHosts + i + 1), grpImporting.readEntry(QStringLiteral("SelectedMech%1").arg(i), QString()));
-        grpExisting.writeEntry(QStringLiteral("SelectedPageSize%1").arg(existingNumberSelectedHosts + i + 1), grpImporting.readEntry(QStringLiteral("SelectedPageSize%1").arg(i), 0));
-        grpExisting.writeEntry(QStringLiteral("SelectedPort%1").arg(existingNumberSelectedHosts + i + 1), grpImporting.readEntry(QStringLiteral("SelectedPort%1").arg(i), 0));
-        grpExisting.writeEntry(QStringLiteral("SelectedPwdBind%1").arg(existingNumberSelectedHosts + i + 1), grpImporting.readEntry(QStringLiteral("SelectedPwdBind%1").arg(i), QString()));
-        grpExisting.writeEntry(QStringLiteral("SelectedSecurity%1").arg(existingNumberSelectedHosts + i + 1), grpImporting.readEntry(QStringLiteral("SelectedSecurity%1").arg(i), QString()));
-        grpExisting.writeEntry(QStringLiteral("SelectedSizeLimit%1").arg(existingNumberSelectedHosts + i + 1), grpImporting.readEntry(QStringLiteral("SelectedSizeLimit%1").arg(i), 0));
-        grpExisting.writeEntry(QStringLiteral("SelectedTimeLimit%1").arg(existingNumberSelectedHosts + i + 1), grpImporting.readEntry(QStringLiteral("SelectedTimeLimit%1").arg(i), 0));
-        grpExisting.writeEntry(QStringLiteral("SelectedUser%1").arg(existingNumberSelectedHosts + i + 1), grpImporting.readEntry(QStringLiteral("SelectedUser%1").arg(i), QString()));
-        grpExisting.writeEntry(QStringLiteral("SelectedVersion%1").arg(existingNumberSelectedHosts + i + 1), grpImporting.readEntry(QStringLiteral("SelectedVersion%1").arg(i), 0));
-        grpExisting.writeEntry(QStringLiteral("SelectedUserFilter%1").arg(existingNumberSelectedHosts + i + 1), grpImporting.readEntry(QStringLiteral("SelectedUserFilter%1").arg(i), 0));
+        const int numberHosts = existingNumberSelectedHosts + i + 1;
+        grpExisting.writeEntry(QStringLiteral("SelectedAuth%1").arg(numberHosts), auth);
+        grpExisting.writeEntry(QStringLiteral("SelectedBase%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("SelectedBase%1").arg(i), QString()));
+        grpExisting.writeEntry(QStringLiteral("SelectedBind%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("SelectedBind%1").arg(i), QString()));
+        grpExisting.writeEntry(QStringLiteral("SelectedHost%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("SelectedHost%1").arg(i), QString()));
+        grpExisting.writeEntry(QStringLiteral("SelectedMech%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("SelectedMech%1").arg(i), QString()));
+        grpExisting.writeEntry(QStringLiteral("SelectedPageSize%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("SelectedPageSize%1").arg(i), 0));
+        grpExisting.writeEntry(QStringLiteral("SelectedPort%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("SelectedPort%1").arg(i), 0));
+        grpExisting.writeEntry(QStringLiteral("SelectedPwdBind%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("SelectedPwdBind%1").arg(i), QString()));
+        grpExisting.writeEntry(QStringLiteral("SelectedSecurity%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("SelectedSecurity%1").arg(i), QString()));
+        grpExisting.writeEntry(QStringLiteral("SelectedSizeLimit%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("SelectedSizeLimit%1").arg(i), 0));
+        grpExisting.writeEntry(QStringLiteral("SelectedTimeLimit%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("SelectedTimeLimit%1").arg(i), 0));
+        grpExisting.writeEntry(QStringLiteral("SelectedUser%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("SelectedUser%1").arg(i), QString()));
+        grpExisting.writeEntry(QStringLiteral("SelectedVersion%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("SelectedVersion%1").arg(i), 0));
+        grpExisting.writeEntry(QStringLiteral("SelectedUserFilter%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("SelectedUserFilter%1").arg(i), 0));
     }
 
     for (int i = 0; i < importingNumberHosts; ++i) {
-        grpExisting.writeEntry(QStringLiteral("Auth%1").arg(existingNumberHosts + i + 1), grpImporting.readEntry(QStringLiteral("Auth%1").arg(i), QString()));
-        grpExisting.writeEntry(QStringLiteral("Base%1").arg(existingNumberHosts + i + 1), grpImporting.readEntry(QStringLiteral("Base%1").arg(i), QString()));
-        grpExisting.writeEntry(QStringLiteral("Bind%1").arg(existingNumberHosts + i + 1), grpImporting.readEntry(QStringLiteral("Bind%1").arg(i), QString()));
-        grpExisting.writeEntry(QStringLiteral("Host%1").arg(existingNumberHosts + i + 1), grpImporting.readEntry(QStringLiteral("Host%1").arg(i), QString()));
-        grpExisting.writeEntry(QStringLiteral("Mech%1").arg(existingNumberHosts + i + 1), grpImporting.readEntry(QStringLiteral("Mech%1").arg(i), QString()));
-        grpExisting.writeEntry(QStringLiteral("PageSize%1").arg(existingNumberHosts + i + 1), grpImporting.readEntry(QStringLiteral("PageSize%1").arg(i), 0));
-        grpExisting.writeEntry(QStringLiteral("Port%1").arg(existingNumberHosts + i + 1), grpImporting.readEntry(QStringLiteral("Port%1").arg(i), 0));
-        grpExisting.writeEntry(QStringLiteral("PwdBind%1").arg(existingNumberHosts + i + 1), grpImporting.readEntry(QStringLiteral("PwdBind%1").arg(i), QString()));
-        grpExisting.writeEntry(QStringLiteral("Security%1").arg(existingNumberHosts + i + 1), grpImporting.readEntry(QStringLiteral("Security%1").arg(i), QString()));
-        grpExisting.writeEntry(QStringLiteral("SizeLimit%1").arg(existingNumberHosts + i + 1), grpImporting.readEntry(QStringLiteral("SizeLimit%1").arg(i), 0));
-        grpExisting.writeEntry(QStringLiteral("TimeLimit%1").arg(existingNumberHosts + i + 1), grpImporting.readEntry(QStringLiteral("TimeLimit%1").arg(i), 0));
-        grpExisting.writeEntry(QStringLiteral("User%1").arg(existingNumberHosts + i + 1), grpImporting.readEntry(QStringLiteral("User%1").arg(i), QString()));
-        grpExisting.writeEntry(QStringLiteral("Version%1").arg(existingNumberHosts + i + 1), grpImporting.readEntry(QStringLiteral("Version%1").arg(i), 0));
-        grpExisting.writeEntry(QStringLiteral("UserFilter%1").arg(existingNumberSelectedHosts + i + 1), grpImporting.readEntry(QStringLiteral("UserFilter%1").arg(i), 0));
+        const int numberHosts = existingNumberHosts + i + 1;
+        grpExisting.writeEntry(QStringLiteral("Auth%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("Auth%1").arg(i), QString()));
+        grpExisting.writeEntry(QStringLiteral("Base%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("Base%1").arg(i), QString()));
+        grpExisting.writeEntry(QStringLiteral("Bind%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("Bind%1").arg(i), QString()));
+        grpExisting.writeEntry(QStringLiteral("Host%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("Host%1").arg(i), QString()));
+        grpExisting.writeEntry(QStringLiteral("Mech%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("Mech%1").arg(i), QString()));
+        grpExisting.writeEntry(QStringLiteral("PageSize%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("PageSize%1").arg(i), 0));
+        grpExisting.writeEntry(QStringLiteral("Port%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("Port%1").arg(i), 0));
+        grpExisting.writeEntry(QStringLiteral("PwdBind%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("PwdBind%1").arg(i), QString()));
+        grpExisting.writeEntry(QStringLiteral("Security%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("Security%1").arg(i), QString()));
+        grpExisting.writeEntry(QStringLiteral("SizeLimit%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("SizeLimit%1").arg(i), 0));
+        grpExisting.writeEntry(QStringLiteral("TimeLimit%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("TimeLimit%1").arg(i), 0));
+        grpExisting.writeEntry(QStringLiteral("User%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("User%1").arg(i), QString()));
+        grpExisting.writeEntry(QStringLiteral("Version%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("Version%1").arg(i), 0));
+        grpExisting.writeEntry(QStringLiteral("UserFilter%1").arg(numberHosts), grpImporting.readEntry(QStringLiteral("UserFilter%1").arg(i), 0));
     }
 
     grpExisting.sync();
