@@ -94,11 +94,6 @@ QString Utils::alarmPath()
     return QStringLiteral("alarm/");
 }
 
-QString Utils::jotPath()
-{
-    return QStringLiteral("jot/");
-}
-
 QString Utils::notePath()
 {
     return QStringLiteral("note/");
@@ -153,13 +148,18 @@ QString Utils::resourcePath(const KSharedConfigPtr &resourceConfig, const QStrin
     return url;
 }
 
-void Utils::convertCollectionIdsToRealPath(KConfigGroup &group, const QString &currentKey)
+//Merge two methods I think
+void Utils::convertCollectionIdsToRealPath(KConfigGroup &group, const QString &currentKey, const QString &prefixCollection)
 {
     if (group.hasKey(currentKey)) {
         const QStringList value = group.readEntry(currentKey, QStringList());
         QStringList newValue;
-        for (const QString &str : value) {
+        for (QString str : value) {
             bool found = false;
+            if (!prefixCollection.isEmpty() && str.startsWith(prefixCollection)) {
+                str = str.remove(0, prefixCollection.length());
+
+            }
             const int collectionId = str.toInt(&found);
             if (found) {
                 const QString realPath = MailCommon::Util::fullCollectionPath(Akonadi::Collection(collectionId));
@@ -168,7 +168,11 @@ void Utils::convertCollectionIdsToRealPath(KConfigGroup &group, const QString &c
                 }
             }
         }
-        group.writeEntry(currentKey, newValue);
+        if (newValue.isEmpty()) {
+            group.deleteEntry(currentKey);
+        } else {
+            group.writeEntry(currentKey, newValue);
+        }
     }
 }
 
@@ -262,7 +266,7 @@ QString Utils::storeResources(KZip *archive, const QString &identifier, const QS
         return i18n("Resource file \"%1\" cannot be added to backup file.", agentFileName);
     }
 
-    const QString agentConfigFileName = QLatin1String("agent_config_") + identifier;
+    const QString agentConfigFileName = Utils::prefixAkonadiConfigFile() + identifier;
     const QString agentConfigFileNamePath = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1String("/akonadi/") + agentConfigFileName;
     if (QFileInfo::exists(agentConfigFileNamePath)) {
         fileAdded = archive->addLocalFile(agentConfigFileNamePath, path + agentConfigFileName);
@@ -373,3 +377,13 @@ QString Utils::storedTypeToI18n(StoredType type)
     qCDebug(PIMSETTINGEXPORTERCORE_LOG) << " type unknown " << type;
     return QString();
 }
+
+
+QString Utils::agentFileName(const QString &filename)
+{
+    QString agentFileConfigName = filename;
+    agentFileConfigName.remove(Utils::resourcesPath());
+    agentFileConfigName.remove(agentFileConfigName.length() - 2, 2); //Remove "rc"
+    agentFileConfigName = Utils::resourcesPath() + Utils::prefixAkonadiConfigFile() + agentFileConfigName;
+    return agentFileConfigName;
+}
